#!/usr/bin/env python
# -*- coding: utf-8 -*-

#import cv2
import sys
import numpy as np
import gdal
def geoint_pr_ndvi(nir_fn, vir_fn, outfile):
	'''!
		Normalized Difference Vegetation Index (NDVI)
		@param nir_fr String: Near Infra Red band (S2_B08) Image file name
		@param vir String: Red Band (S2_B04) Image file name
		@param outfile String: NDVI image file name
	'''
	nir = gdal.Open(nir_fn)
	red = gdal.Open(vir_fn)

	rows, cols, geotransform = nir.RasterYSize, nir.RasterXSize, nir.GetGeoTransform()

#	# Read the input bands as numpy arrays.
	np_nir = nir.GetRasterBand(1).ReadAsArray(0,0,nir.RasterXSize, nir.RasterYSize)
	np_red = red.GetRasterBand(1).ReadAsArray(0,0,red.RasterXSize, red.RasterYSize) 

	# Convert the np arrays to 32-bit floating point to make sure division will occur properly.
	np_nir_as32 = np_nir.astype(np.float32)
	np_red_as32 = np_red.astype(np.float32)

	# Calculate the NDVI formula.
	np.seterr(divide='ignore', invalid='ignore')
	numerator = np.subtract(np_nir_as32, np_red_as32)
	denominator = np.add(np_nir_as32, np_red_as32)
	result = np.divide(numerator, denominator)
	result = np.multiply((result + 1), (2**7 - 1))

	driverTiff = gdal.GetDriverByName('GTiff')
#	driverJP2 = gdal.GetDriverByName('JP2OpenJPEG')
#	driverJP2ECW = gdal.GetDriverByName('JP2ECW')
#	raster = np.zeros((rows, cols), dtype=np.uint8)
	output = driverTiff.Create(outfile, cols, rows, 1, gdal.GDT_Byte)
#	output = driverTiff.CreateCopy(outfile+".tiff", nir, strict=0)
#	output = driverJP2.CreateCopy(outfile, nir, strict=0)
	output.GetRasterBand(1).SetNoDataValue(-99)
	output.GetRasterBand(1).WriteArray(result)
	output.GetRasterBand(1).FlushCache()
	output.SetGeoTransform(geotransform)
	output = None


def main(argv):
	geoint_pr_ndvi(argv[1], argv[2], argv[3])

if __name__ == "__main__":
	main(sys.argv)
